#
# spec file for package ThePEG
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           ThePEG
Version:        2.0.4
Release:        1.1
Summary:        Toolkit providing a common platform for event generators in C++
License:        GPL-2.0
Group:          Development/Libraries/C and C++
Url:            http://home.thep.lu.se/~leif/ThePEG/
Source:         http://www.hepforge.org/archive/thepeg/%{name}-%{version}.tar.bz2
Patch1:         ThePEG_gcc6_failed.patch
BuildRequires:  HepMC-devel
BuildRequires:  LHAPDF-devel
BuildRequires:  Rivet-devel
BuildRequires:  YODA-devel
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_test-devel
%else
BuildRequires:  boost-devel
%endif
BuildRequires:  fastjet-devel
BuildRequires:  fastjet-plugin-siscone-devel
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gsl-devel
BuildRequires:  java-devel
BuildRequires:  pkgconfig(zlib)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
ThePEG project is a toolkit for providing a common platform for using and
building event generators in C++.


%package -n ThePEG-libs
Summary:        Toolkit providing a common platform for event generators in C++
Group:          System/Libraries
Obsoletes:      libThePEG24 < %{version}-%{release}
Provides:       libThePEG24 = %{version}-%{release}

%description -n ThePEG-libs
ThePEG project is a toolkit for providing a common platform for using and
building event generators in C++.

This package provides the shared libraries for ThePEG.

%package devel
Summary:        Toolkit providing a common platform for event generators in C++
Group:          Development/Libraries/C and C++
Requires:       ThePEG-libs = %{version}

%description devel
ThePEG project is a toolkit for providing a common platform for using and
building event generators in C++.

This package provides the header and source files needed for development with
ThePEG.

%prep
%setup -q
%patch1 -p1

%build
%configure
make %{?_smp_mflags}

%install
%make_install
mkdir -p %{buildroot}/%{_sysconfdir}/ld.so.conf.d
cat << EOF > %{buildroot}/%{_sysconfdir}/ld.so.conf.d/%{name}.conf
%{_libdir}/%{name}
EOF

find %{buildroot}%{_libdir}/%{name} -name "*.la" -delete
%fdupes -s %{buildroot}%{_libdir}/%{name}/

%post   -n ThePEG-libs -p /sbin/ldconfig
%postun -n ThePEG-libs -p /sbin/ldconfig

%files -n ThePEG-libs
%defattr(-,root,root)
%doc AUTHORS GUIDELINES ChangeLog NEWS README COPYING
%config %{_sysconfdir}/ld.so.conf.d/%{name}.conf
%dir %{_libdir}/%{name}/
%{_libdir}/%{name}/*.so.*

%files devel
%defattr(-,root,root)
%{_bindir}/thepeg
%{_bindir}/runThePEG
%{_bindir}/setupThePEG
%{_includedir}/%{name}/
%dir %{_libdir}/%{name}/
%{_libdir}/%{name}/*.so
%{_libdir}/%{name}/Makefile
%{_libdir}/%{name}/Makefile.common
%{_libdir}/%{name}/ThePEGDefaults-%{version}.rpo
%{_libdir}/%{name}/ThePEGDefaults.rpo
%{_libdir}/%{name}/runThePEG-%{version}
%{_libdir}/%{name}/setupThePEG-%{version}
%{_libdir}/%{name}/ThePEG.jar
%{_datadir}/%{name}/

%changelog
* Mon Feb 13 2017 jengelh@inai.de
- Rename from libThePEG24 to ThePEG-libs as the package does not
  satisfy the SLPP guideline: there are a number of non-.so.24
  files.
* Thu Feb  2 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Thu Nov 10 2016 badshah400@gmail.com
- Update to version 2.0.4:
  * Default weight explicitly labelled: The nominal event weight
    is now labelled "Default" and is always the first weight to be
    inserted into HepMC.
  * LesHouches event weights handling: There are now two options
    for the treatment of optional weights coming in from a Les
    Houches file, available through
    "LesHouchesEventHandler:WeightNormalization". Either they are
    normalized to the "Default" weight ("Normalized"), or they are
    given as cross-sections in pb ("CrossSection"). The default
    behaviour is "Normalized".
  * JetFinder in Cuts objects writes information: The selected
    JetFinder is explicitly listed in the debug output.
- Lots of changes from version 1.9.2 (last packaged) through
  v2.0.3; please see NEWS file for details.
- Add java-devel BuildRequires; required to build new GUI.
- Add YODA-devel BuildRequires; required for configuring Rivet
  during build.
* Sun Jun 19 2016 jengelh@inai.de
- RPM group classification and direct use of ldconfig
* Thu Jun 16 2016 normand@linux.vnet.ibm.com
- new ThePEG_gcc6_failed.patch to avoid gcc6 build failure
  tracked upstream by
  https://herwig.hepforge.org/trac/ticket/4
* Thu Sep  4 2014 badshah400@gmail.com
- Update to version 1.9.2:
  + Better support for LHAPDF 6; now determines if version 6 is
    available and makes use of new LHAPDFv6 features
- Changes from version 1.9.1:
  + Build fix for SLC6
  + Build fix for Rivet 2.1.1: adapted to Rivet 2.1.1 changed
    header file layout
- Use macro instead of hard-coding version in file-list.
* Sat Dec  7 2013 badshah400@gmail.com
- Initial version
